@@ -26,12 +26,12 @@
 #include "statisticsprovider.h"
 #include "wakeupmodel.h"
 
-K_PLUGIN_FACTORY_WITH_JSON(KCMEnergyInfoFactory, "kcm_energyinfo.json", registerPlugin<KCMEnergyInfo>();)
+K_PLUGIN_CLASS_WITH_JSON(KCMEnergyInfo, "kcm_energyinfo.json")
 
 using namespace KQuickAddons;
 
-KCMEnergyInfo::KCMEnergyInfo(QObject *parent, const QVariantList &args)
-    : ConfigModule(parent, args)
+KCMEnergyInfo::KCMEnergyInfo(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : ConfigModule(parent, data, args)
 {
     qmlRegisterAnonymousType<BatteryModel>("org.kde.kinfocenter.energy.private", 1);
     qmlRegisterAnonymousType<WakeUpModel>("org.kde.kinfocenter.energy.private", 1);
