@@ -21,8 +21,8 @@ class KCMEnergyInfo : public KQuickAddons::ConfigModule
     Q_PROPERTY(WakeUpModel *wakeUps READ wakeUps CONSTANT)
 
 public:
-    explicit KCMEnergyInfo(QObject *parent, const QVariantList &args);
-    virtual ~KCMEnergyInfo() = default;
+    explicit KCMEnergyInfo(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
+    ~KCMEnergyInfo() override = default;
 
     BatteryModel *batteries() const
     {
